#!/bin/sh

# Sets up a web development environment for CaneyPUGgies in a base Ubuntu installation
echo "Setting up a web development environment for CaneyPUGgies..."

setupdir=~/Desktop/CaneyPUGgies_env_setup
mkdir $setupdir
cd $setupdir

# Skype
echo " - Installing Skype..."
yum install glib2.i386 qt4.i386 zlib.i386 alsa-lib.i386 libX11.i386 libXv.i386 libXScrnSaver.i386 
echo "   - Installing to /opt (tweak to taste)..."
cd /tmp
wget http://www.skype.com/go/getskype-linux-beta-static
cd /opt
tar jxvf /tmp/skype_static-2.2.0.35.tar.bz2
ln -s skype_static-2.2.0.35 skype
echo "   - You need to replace the version number to match the one downloaded. At the time of this writing, it is 2.2.0.35."
echo "   - Setting some symlinks (the first is required for sounds to work, the second is optional)..."
ln -s /opt/skype /usr/share/skype
ln -s /opt/skype/skype /usr/bin/skype

# Google Chrome
echo " - Adding Google Chrome repository..."
# TODO:  I'm not sure a simple double-quote will properly contain this multi-line string in sh, but it seems to work on the command line.
echo "[google]
name=Google - i386
baseurl=http://dl.google.com/linux/rpm/stable/i386
enabled=1
gpgcheck=1
gpgkey=https://dl-ssl.google.com/linux/linux_signing_key.pub" | sudo tee -a /etc/yum.repos.d/google.repo > /dev/null

sudo yum update

echo "Installing software available in CentOS's repositories via yum..."
sudo yum install empathy skype vinagre bzr bzrtools bzr-explorer google-chrome-stable dkms sqlite3
echo "PLEASE NOTE: If you want to do screen sharing through Yuuguu, please download & install Yuuguu here:  http://www.yuuguu.com/download/fedora_download"
echo "PLEASE NOTE: To run Eclipse or Yuuguu, you will need to manually install Sun Java 6, perhaps as described here: http://wiki.centos.org/HowTos/JavaOnCentOS"
echo " "
read -p "Press ENTER to continue: " enter
echo " "

echo "Installing software that must be downloaded & installed manually..."

echo "Creating TurboGears 2.1 environment in the ~/Projects directory..."
echo " - Installing TurboGears dependencies"
sudo yum install build-essential python-dev python-setuptools python-virtualenv
echo " - Creating Virtual Environment..."
mkdir ~/Projects
cd ~/Projects

# Create virtual environment
virtualenv --no-site-packages tg21env
cd tg21env
# Activate virtual environment
# Note this command is equivalent to "source bin/activate" in bash, but we're using sh instead of bash
. bin/activate

# Install TurboGears 2.1
# TODO: For some reason this returns this error:
# error: Installed distribution ToscaWidgets 0.8.7.1dev-20110704 conflicts with requirement ToscaWidgets>0.9.7
easy_install -i http://www.turbogears.org/2.1/downloads/current/index tg.devtools
# Install sqlalchemy-migrate
easy_install sqlalchemy-migrate

# Upgrade toscawidgets to >0.9.7
easy_install -U toscawidgets
# Upgrade genshi
easy_install -U genshi
# Fix ImportError: No module named pylonshq
easy_install repoze.what_pylons

# Get branch of Reformed Churches Locator
echo " - Making a local branch of the RCL Bazaar repository..."
cd ..
bzr branch lp:reformedchurcheslocator
echo " - Installing RCL into this virtual environment, downloading required packages..."
cd reformedchurcheslocator
python setup.py develop
echo " - Running nosetests as a smoke test to see if this TurboGears app is installed correctly..."
nosetests

echo " - HERE'S WHAT YOU NEED TO DO AFTER PRESSING 'ENTER' BELOW:"
echo "   1.  CTRL-click on the link in the terminal to open the Reformed Churches Locator application in your browser."
echo "   2.  Click around, login, play with the admin interface a little."
echo "   3.  If it's running satisfactorily, hit CTRL-C to kill the app."
echo " "
echo " - If something didn't work right, just delete the tg21env & reformedchurcheslocator directories in ~/Projects, (ask for help) fix(ing) this script, and try running it again."
echo " "
echo " - If everything installed correctly, then this installer is ALL DONE!"
echo " "
read -p "Press ENTER to continue: " enter
echo " "

echo " - Creating app's database & serving on default port (port 8080)..."
echo " "
paster setup-app development.ini
paster serve --reload development.ini


