#!/bin/sh

# Sets up a web development environment for CaneyPUGgies in a base Ubuntu installation
echo "Setting up a web development environment for CaneyPUGgies..."

setupdir=~/Desktop/CaneyPUGgies_env_setup
mkdir $setupdir
cd $setupdir

echo "Adding extra repositories..."
# Google Chrome
echo " - Adding Google Chrome repository..."
echo "deb http://dl.google.com/linux/chrome/deb/ stable main" | sudo tee -a /etc/apt/sources.list > /dev/null
# TODO: See if we can join the above and below lines into one by deleting the above line
echo "deb http://dl.google.com/linux/deb/ stable non-free main" | sudo tee -a /etc/apt/sources.list > /dev/null
# Key for Google Chrome
sudo apt-key adv --keyserver keyserver.ubuntu.com --recv-keys A040830F7FAC5991

echo "Installing web development software..."
sudo apt-get -y --force-yes install gedit gimp inkscape empathy skype bzr bzrtools bzr-git bzr-svn bzr-explorer meld groundcontrol dkms cvs wine clamav clamtk openjdk-7-jre python-wxgtk2.6 python-wxgtk2.8 bicyclerepair nautilus-actions sqlite3 google-chrome-stable nautilus-compare

# TODO: Set Chrome as the default browser

echo "Configuring gedit's preferences to enable the following features:"
echo " - Display line numbers"
gconftool-2 --set /apps/gedit-2/preferences/editor/line_numbers/display_line_numbers --type bool true
echo " - Highlight current line"
gconftool-2 --set /apps/gedit-2/preferences/editor/current_line/highlight_current_line --type bool true
echo " - Auto indent"
gconftool-2 --set /apps/gedit-2/preferences/editor/auto_indent/auto_indent --type bool true
echo " - Highlight matching bracket"
gconftool-2 --set /apps/gedit-2/preferences/editor/bracket_matching/bracket_matching --type bool true
echo " - Auto save"
gconftool-2 --set /apps/gedit-2/preferences/editor/save/auto_save --type bool true
gconftool-2 --set /apps/gedit-2/preferences/editor/save/create_backup_copy --type bool true
echo " - Tabs"
gconftool-2 --set /apps/gedit-2/preferences/editor/tabs/insert_spaces --type bool true
gconftool-2 --set /apps/gedit-2/preferences/editor/tabs/tabs_size --type int 4

echo "Installing software that must be downloaded & installed manually..."
# Follow http://help.eclipse.org/help33/index.jsp?topic=/org.eclipse.platform.doc.isv/reference/misc/update_standalone.html
echo " - Eclipse"
wget http://ftp.ussg.iu.edu/eclipse/technology/epp/downloads/release/indigo/R/eclipse-javascript-indigo-linux-gtk.tar.gz
tar -xzf eclipse-javascript-indigo-linux-gtk.tar.gz
rm eclipse-javascript-indigo-linux-gtk.tar.gz
mkdir ~/.eclipse
mv eclipse/* eclipse/.e* ~/.eclipse
rm -rf eclipse
# Git is an Aptana dependency
sudo apt-get -y install git
echo " - Aptana"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.aptana.com/studio3/plugin/install -installIU com.aptana.feature.studio.feature.group
# Copy in bash script to start Aptana using sun-java6
cat >> ~/.eclipse/runEclipse.sh << EOF
#!/bin/sh
export MOZILLA_FIVE_HOME=/usr/lib/xulrunner
export JAVA_HOME=/usr/lib/jvm/java-6-sun/jre
# Fix for "Finish" button that has to be selected then press enter to get it to work, http://bbs.archlinux.org/viewtopic.php?id=82894
export GDK_NATIVE_WINDOWS=true
~/.eclipse/eclipse
EOF
# Make the new script executable
chmod ug+x ~/.eclipse/runEclipse.sh
wget http://bazaar.launchpad.net/~caneypuggies/+junk/CaneyPUGgies_tools/download/tim%40alwaysreformed.com-20100602185436-ztla7n29ghi82iqv/aptana_64.png-20100602185333-933pbn544c7s8dtk-10/aptana_64.png
mkdir icons
mv aptana_64.png icons
mv icons ~/.eclipse
cat >> ~/.eclipse/Aptana.desktop << EOF
#!/usr/bin/env xdg-open

[Desktop Entry]
Version=1.0
Type=Application
Terminal=false
Icon[en_US]=gnome-panel-launcher
Name[en_US]=Aptana IDE
Exec=$HOME/.eclipse/runEclipse.sh
Comment[en_US]=Aptana Web Development Integrated Development Environment
Name=Aptana IDE
Comment=Aptana Web Development Integrated Development Environment
Icon=$HOME/.eclipse/icons/aptana_64.png
EOF
chmod ug+x ~/.eclipse/Aptana.desktop
# TODO: Put Aptana in Programming menu with Aptana icon
# TODO: Put Aptana in Unity launcher
# Temporary workaround:  Put link to Aptana on the desktop
ln -s ~/.eclipse/Aptana.desktop ~/Desktop
echo " - Enabling Aptana Web perspective..."
# TODO: This doesn't open the Aptana perspective yet, so you have to open it manually
# TODO: It appears the "Aptana" perspective has been removed, and what is left is the "PyDev" perspective.
echo "     *********************************************"
echo " - - NOTE: Please close the program named 'Eclipse' after it starts up.  This installation script will not continue installing anything until you close Eclipse."
echo "     *********************************************"
~/.eclipse/eclipse -perspective "Aptana"
echo " - JSDT jQuery Integration (jQuery autocomplete support)"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository https://svn.codespot.com/a/eclipselabs.org/jsdt-jquery/updatesite -installIU org.eclipselabs.jsdt.jquery_feature.feature.group
# Install Eclipse Web Developer Tools
echo " - Eclipse Web Developer Tools / Web Tools Platform (WTP)"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/releases/indigo/ -installIU org.eclipse.wst.web_ui.feature.feature.group
# Install PDT PHP Development Tools
echo " - PDT PHP Development Tools"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository  http://download.eclipse.org/releases/indigo -installIU org.eclipse.php.sdk.feature.group
echo " - oPDT extension to PHP Development Tools"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository  http://opdt.openway.com.pl/ -installIU pl.com.openway.opdt.feature.feature.group
echo " - Mylyn, task-focused interface"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/mylyn/releases/latest -installIU org.eclipse.mylyn_feature.feature.group
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/mylyn/releases/latest -installIU org.eclipse.mylyn.context_feature.feature.group
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/mylyn/releases/latest -installIU org.eclipse.mylyn.ide_feature.feature.group
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/mylyn/releases/latest -installIU org.eclipse.mylyn.team_feature.feature.group
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/mylyn/releases/latest -installIU org.eclipse.mylyn.trac_feature.feature.group
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://pydev.org/updates -installIU org.python.pydev.mylyn.feature.feature.group
echo " - Eclipse Communication Framework, for collaborative editing"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/rt/ecf/3.5.1/site.p2 -installIU org.eclipse.ecf.core.feature.group
# TODO: This is commented out because it complains that it needs org.junit 0.0.0
<<COMMENT-QBZR
# Install QBzr-Eclipse
echo " - QBzr for integration with the Bazaar version control system"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://development.bitwig.com/qbzr-eclipse -installIU org.bazaar_vcs.qbzr_eclipse.feature.group/0.11.0
COMMENT-QBZR

echo " - Boa Constructor..."
echo " - - Please press ENTER when asked for a password."
cvs -d:pserver:anonymous@boa-constructor.cvs.sourceforge.net:/cvsroot/boa-constructor login 
cvs -z3 -d:pserver:anonymous@boa-constructor.cvs.sourceforge.net:/cvsroot/boa-constructor co -P boa 
mkdir ~/.boa-constructor-src
mv boa/* boa/.cvs* ~/.boa-constructor-src
rm -rf boa
cat >> ~/.boa-constructor-src/Boa.desktop << EOF
#!/usr/bin/env xdg-open

[Desktop Entry]
Version=1.0
Type=Application
Terminal=false
Icon[en_US]=gnome-panel-launcher
Name[en_US]=Boa Constructor
Exec=$HOME/.boa-constructor-src/Boa.py
Comment[en_US]=Boa Constructor Python Integrated Development Environment
Name=Boa Constructor
Comment=Boa Constructor Python Integrated Development Environment
Icon=$HOME/.boa-constructor-src/Images/Icons/Boa.ico
EOF
chmod ug+x ~/.boa-constructor-src/Boa.desktop
chmod ug+x ~/.boa-constructor-src/Boa.py
# TODO: Put Boa in Programming menu with Aptana icon
# Temporary workaround:  Put link to Boa on the desktop
ln -s ~/.boa-constructor-src/Boa.desktop ~/Desktop

echo " - gedit plugins:  Auto Tab, Indent Lines, Reindent Python, Reopen Tabs, Snippets, Tab Close, Word Completion..."
# Download/extract to ~/.gnome2/gedit/plugins/
mkdir ~/.local/share/gedit
mkdir ~/.local/share/gedit/plugins
cd ~/.local/share/gedit/plugins
echo " - - Auto Tab"
wget http://gedit-autotab.googlecode.com/files/autotab-0.6.tar.gz
tar -xzf autotab-0.6.tar.gz
rm autotab-0.6.tar.gz
echo " - - Indent Lines"
wget -O reindent.gedit-plugin "http://live.gnome.org/Gedit/Plugins/Reindent?action=AttachFile&do=get&target=reindent.gedit-plugin"
wget -O reindent.py "http://live.gnome.org/Gedit/Plugins/Reindent?action=AttachFile&do=get&target=reindent.py"
echo " - - Reopen Tabs"
wget http://reopen-tabs-gedit-plugin.googlecode.com/files/reopen-tabs-gedit-plugin-0.3.5.tar.gz
tar -xzf reopen-tabs-gedit-plugin-0.3.5.tar.gz
rm reopen-tabs-gedit-plugin-0.3.5.tar.gz
echo " - - Tab Close"
wget http://blog.goranrakic.com/archives/fajlovi/gedit-tabclose-1.0.tar.gz
tar -xzf gedit-tabclose-1.0.tar.gz
mv gedit-tabclose/TabClose* .
rm gedit-tabclose-1.0.tar.gz
rm -rf gedit-tabclose
echo " - - Reopen Tabs"
wget http://reopen-tabs-gedit-plugin.googlecode.com/files/reopen-tabs-gedit-plugin-0.3.5.tar.gz
tar -xzf reopen-tabs-gedit-plugin-0.3.5.tar.gz
rm reopen-tabs-gedit-plugin-0.3.5.tar.gz
# echo " - - Word Completion"
# TODO: Try the default plugin for word completion, or http://elias.hiex.at/gedit-plugins/ as a replacement
# wget http://users.tkk.fi/~otsaloma/gedit/completion.gedit-plugin
# wget http://users.tkk.fi/~otsaloma/gedit/completion.png
# wget http://users.tkk.fi/~otsaloma/gedit/completion.py
# TODO: Try default bracket completion plugin, or http://code.google.com/p/gedit-pair-char-autocomplete/ for paired character completion
# TODO: Enable these default plugins:  code comment, multiedit, smart spaces, tag list, word completion, bracket completion
# Cleanup the extra files that were unzipped from several plugins
rm CHANGELOG
rm README
# Snippets is already installed by default
echo " - - Enabling gedit plugins..."
gedit_plugins=$(gconftool-2 --get /apps/gedit-2/plugins/active-plugins)
gedit_plugins=$(echo $gedit_plugins | tr -d "[]")
gedit_plugins="[$gedit_plugins,snippets,autotab,reopen-tabs,completion,TabClose,reindent,indent]"
gconftool-2 --set /apps/gedit-2/plugins/active-plugins --type list --list-type string $gedit_plugins
echo " - Installing Nautilus file templates..."
cd $setupdir
wget http://bazaar.launchpad.net/%7Ecaneypuggies/%2Bjunk/CaneyPUGgies_tools/download/tim%40alwaysreformed.com-20100602203740-wgrq5zqdhn8g4l5y/templates.tar.gz-20100602203722-fw7xyz1t8lj446jp-1/Templates.tar.gz
tar -xzf Templates.tar.gz
mv Templates/* ~/Templates
rm Templates.tar.gz
rm -rf Templates

echo "Installing Node.js and virtualenvironment..."
sudo apt-get install nodejs python-virtualenv

echo "Installing couchapp dependencies..."
sudo apt-get -y --force-yes install curl

echo "Creating Python virtual environment named 'couchapp'..."

cd ~/Projects
virtualenv couchapp
echo "Activating virtualenv..."
. couchapp/bin/activate
echo "Installing couchapp..."
pip install couchapp
echo "Getting Bazaar branch of Reformed Churches Locator code..."
cd couchapp
bzr branch lp:reformedchurcheslocator/couchapp rcl
echo "Starting up Reformed Churches Locator..."
cd rcl
./autopush.sh

