#!/bin/sh

# Sets up a web development environment for CaneyPUGgies in a base Ubuntu installation
echo "Setting up a web development environment for CaneyPUGgies..."

setupdir=~/Desktop/CaneyPUGgies_env_setup
mkdir $setupdir
cd $setupdir

echo "Adding extra repositories..."
# Google Chrome
echo " - Adding Google Chrome repository..."
echo "deb http://dl.google.com/linux/chrome/deb/ stable main" | sudo tee -a /etc/apt/sources.list > /dev/null
# echo "deb http://dl.google.com/linux/deb/ stable non-free" | sudo tee -a /etc/apt/sources.list > /dev/null
# TODO: See if we can join the above and below lines into one by deleting the above line
echo "deb http://dl.google.com/linux/deb/ stable non-free main" | sudo tee -a /etc/apt/sources.list > /dev/null
# Key for Google Chrome
sudo apt-key adv --keyserver keyserver.ubuntu.com --recv-keys A040830F7FAC5991
# Sun Java 6
echo " - Adding sun-java6-jre repository for Yuuguu & Eclipse..."
echo "deb http://archive.canonical.com/ubuntu lucid partner" | sudo tee -a /etc/apt/sources.list > /dev/null
echo "deb-src http://archive.canonical.com/ubuntu lucid partner" | sudo tee -a /etc/apt/sources.list > /dev/null
echo "deb http://update.yuuguu.com/repositories/apt hardy multiverse" | sudo tee -a /etc/apt/sources.list > /dev/null
wget http://www.yuuguu.com/repositories/yuuguu.asc
sudo apt-key add yuuguu.asc
rm yuuguu.asc

sudo apt-get update

# TODO: install remote-help-assistant # but it crashes on my system - see if its creator answers my bug report
# TODO: Find a way to install giver on 11.10+
echo "Installing software available in Ubuntu's repositories via apt-get..."
sudo apt-get -y --force-yes install gedit gimp inkscape empathy skype yuuguu vinagre bzr bzrtools bzr-git bzr-svn bzr-explorer meld groundcontrol google-chrome-stable dkms cvs wine clamav clamtk sun-java6-jre python-wxgtk2.6 python-wxgtk2.8 xulrunner-1.9.2 bicyclerepair nautilus-actions sqlite3

# TODO: Set Chrome as the default browser

echo "Configuring gedit's preferences to enable the following features:"
echo " - Display line numbers"
gconftool-2 --set /apps/gedit-2/preferences/editor/line_numbers/display_line_numbers --type bool true
echo " - Highlight current line"
gconftool-2 --set /apps/gedit-2/preferences/editor/current_line/highlight_current_line --type bool true
echo " - Auto indent"
gconftool-2 --set /apps/gedit-2/preferences/editor/auto_indent/auto_indent --type bool true
echo " - Highlight matching bracket"
gconftool-2 --set /apps/gedit-2/preferences/editor/bracket_matching/bracket_matching --type bool true
echo " - Auto save"
gconftool-2 --set /apps/gedit-2/preferences/editor/save/auto_save --type bool true
gconftool-2 --set /apps/gedit-2/preferences/editor/save/create_backup_copy --type bool true
echo " - Tabs"
gconftool-2 --set /apps/gedit-2/preferences/editor/tabs/insert_spaces --type bool true
gconftool-2 --set /apps/gedit-2/preferences/editor/tabs/tabs_size --type int 4

echo "Installing Firefox extensions..."
echo " - firebug"
wget https://addons.mozilla.org/firefox/downloads/latest/1843/addon-1843-latest.xpi
firefox -quiet -safe-mode -install-global-extension addon-1843-latest.xpi &
read -p "Press ENTER after installing the extension AND allowing Firefox to restart (if it asks to restart): " enter
rm addon-1843-latest.xpi
echo " - webdeveloper"
wget https://addons.mozilla.org/firefox/downloads/latest/60/addon-60-latest.xpi
firefox -quiet -safe-mode -install-global-extension addon-60-latest.xpi &
read -p "Press ENTER after installing the extension AND allowing Firefox to restart (if it asks to restart): " enter
rm addon-60-latest.xpi
# TODO: Aardvark is not yet compatible with Firefox 5, so this is commented out
<<COMMENT-aardvaark
echo " - aardvark"
wget https://addons.mozilla.org/firefox/downloads/latest/4111/addon-4111-latest.xpi
firefox -quiet -safe-mode -install-global-extension addon-4111-latest.xpi &
read -p "Press ENTER after installing the extension AND allowing Firefox to restart (if it asks to restart): " enter
rm addon-4111-latest.xpi
COMMENT-aardvaark
echo " - colorzilla"
wget https://addons.mozilla.org/firefox/downloads/latest/271/addon-271-latest.xpi
firefox -quiet -safe-mode -install-global-extension addon-271-latest.xpi &
read -p "Press ENTER after installing the extension AND allowing Firefox to restart (if it asks to restart): " enter
rm addon-271-latest.xpi
killall firefox
killall firefox-bin

# TODO: This error appears around this line in this script, maybe because of the backticks in the comment below:
# ./CaneyPUGgies_env_setup.sh: 1: Bad substitution

# TODO: Configure Firefox preferences by creating a custom user.js and copying it into the default profile, which can be found by reading ~/.mozilla/firefox/profiles.ini
<<COMMENT1
profile_path=`grep -m 1 Path ~/.mozilla/firefox/profiles.ini` # the default profile should be the first and only one in the Ubuntu installation so far
profile_path=${profile_path/Path=}; # cut off the initial "Path="
rdf=~/.mozilla/firefox/$profile_path/localstore.rdf
#  - hide Web Developer toolbar
# replace
needle='  <RDF:Description RDF:about="chrome://browser/content/browser.xul#webdeveloper-toolbar"
                   collapsed="false" />'
# with
replace='  <RDF:Description RDF:about="chrome://browser/content/browser.xul#webdeveloper-toolbar"
                   collapsed="true" />'
# TODO: For some reason this sets the above to collapsed="", which is why this whole section is commented out
sed -i 's/$needle/$replace/g' $rdf
#  - hide Bookmarks toolbar
# replace
needle='  <RDF:Description RDF:about="chrome://browser/content/browser.xul#PersonalToolbar"
                   collapsed="false" />'
# with
replace='  <RDF:Description RDF:about="chrome://browser/content/browser.xul#PersonalToolbar"
                   collapsed="true" />'
sed -i 's/$needle/$replace/g' $rdf
#  - hide Menu bar
# replace
needle='  <RDF:Description RDF:about="chrome://browser/content/browser.xul#toolbar-menubar"
                   autohide="false" />'
# with
replace='  <RDF:Description RDF:about="chrome://browser/content/browser.xul#toolbar-menubar"
                   autohide="true" />'
sed -i 's/$needle/$replace/g' $rdf
COMMENT1

echo "Installing software that must be downloaded & installed manually..."
# Follow http://help.eclipse.org/help33/index.jsp?topic=/org.eclipse.platform.doc.isv/reference/misc/update_standalone.html
echo " - Eclipse"
wget http://ftp.ussg.iu.edu/eclipse/technology/epp/downloads/release/indigo/R/eclipse-javascript-indigo-linux-gtk.tar.gz
tar -xzf eclipse-javascript-indigo-linux-gtk.tar.gz
rm eclipse-javascript-indigo-linux-gtk.tar.gz
mkdir ~/.eclipse
mv eclipse/* eclipse/.e* ~/.eclipse
rm -rf eclipse
# Git is an Aptana dependency
sudo apt-get -y install git
echo " - Aptana"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.aptana.com/studio3/plugin/install -installIU com.aptana.feature.studio.feature.group
# Copy in bash script to start Aptana using sun-java6
cat >> ~/.eclipse/runEclipse.sh << EOF
#!/bin/sh
export MOZILLA_FIVE_HOME=/usr/lib/xulrunner
export JAVA_HOME=/usr/lib/jvm/java-6-sun/jre
# Fix for "Finish" button that has to be selected then press enter to get it to work, http://bbs.archlinux.org/viewtopic.php?id=82894
export GDK_NATIVE_WINDOWS=true
~/.eclipse/eclipse
EOF
# Make the new script executable
chmod ug+x ~/.eclipse/runEclipse.sh
wget http://bazaar.launchpad.net/~caneypuggies/+junk/CaneyPUGgies_tools/download/tim%40alwaysreformed.com-20100602185436-ztla7n29ghi82iqv/aptana_64.png-20100602185333-933pbn544c7s8dtk-10/aptana_64.png
mkdir icons
mv aptana_64.png icons
mv icons ~/.eclipse
cat >> ~/.eclipse/Aptana.desktop << EOF
#!/usr/bin/env xdg-open

[Desktop Entry]
Version=1.0
Type=Application
Terminal=false
Icon[en_US]=gnome-panel-launcher
Name[en_US]=Aptana IDE
Exec=$HOME/.eclipse/runEclipse.sh
Comment[en_US]=Aptana Web Development Integrated Development Environment
Name=Aptana IDE
Comment=Aptana Web Development Integrated Development Environment
Icon=$HOME/.eclipse/icons/aptana_64.png
EOF
chmod ug+x ~/.eclipse/Aptana.desktop
# TODO: Put Aptana in Programming menu with Aptana icon
# TODO: Put Aptana in Unity launcher
# Temporary workaround:  Put link to Aptana on the desktop
ln -s ~/.eclipse/Aptana.desktop ~/Desktop
echo " - Enabling Aptana Web perspective..."
# TODO: This doesn't open the Aptana perspective yet, so you have to open it manually
# TODO: It appears the "Aptana" perspective has been removed, and what is left is the "PyDev" perspective.
echo "     *********************************************"
echo " - - NOTE: Please close the program named 'Eclipse' after it starts up.  This installation script will not continue installing anything until you close Eclipse."
echo "     *********************************************"
~/.eclipse/eclipse -perspective "Aptana"
echo " - JSDT jQuery Integration (jQuery autocomplete support)"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository https://svn.codespot.com/a/eclipselabs.org/jsdt-jquery/updatesite -installIU org.eclipselabs.jsdt.jquery_feature.feature.group
# Install Eclipse Web Developer Tools
echo " - Eclipse Web Developer Tools / Web Tools Platform (WTP)"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/releases/indigo/ -installIU org.eclipse.wst.web_ui.feature.feature.group
# Install PDT PHP Development Tools
echo " - PDT PHP Development Tools"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository  http://download.eclipse.org/releases/indigo -installIU org.eclipse.php.sdk.feature.group
echo " - oPDT extension to PHP Development Tools"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository  http://opdt.openway.com.pl/ -installIU pl.com.openway.opdt.feature.feature.group
echo " - Mylyn, task-focused interface"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/mylyn/releases/latest -installIU org.eclipse.mylyn_feature.feature.group
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/mylyn/releases/latest -installIU org.eclipse.mylyn.context_feature.feature.group
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/mylyn/releases/latest -installIU org.eclipse.mylyn.ide_feature.feature.group
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/mylyn/releases/latest -installIU org.eclipse.mylyn.team_feature.feature.group
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/mylyn/releases/latest -installIU org.eclipse.mylyn.trac_feature.feature.group
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://pydev.org/updates -installIU org.python.pydev.mylyn.feature.feature.group
echo " - Eclipse Communication Framework, for collaborative editing"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://download.eclipse.org/rt/ecf/3.5.1/site.p2 -installIU org.eclipse.ecf.core.feature.group
# TODO: This is commented out because it complains that it needs org.junit 0.0.0
<<COMMENT-QBZR
# Install QBzr-Eclipse
echo " - QBzr for integration with the Bazaar version control system"
~/.eclipse/eclipse -application org.eclipse.equinox.p2.director -repository http://development.bitwig.com/qbzr-eclipse -installIU org.bazaar_vcs.qbzr_eclipse.feature.group/0.11.0
COMMENT-QBZR

echo " - Boa Constructor..."
echo " - - Please press ENTER when asked for a password."
cvs -d:pserver:anonymous@boa-constructor.cvs.sourceforge.net:/cvsroot/boa-constructor login 
cvs -z3 -d:pserver:anonymous@boa-constructor.cvs.sourceforge.net:/cvsroot/boa-constructor co -P boa 
mkdir ~/.boa-constructor-src
mv boa/* boa/.cvs* ~/.boa-constructor-src
rm -rf boa
cat >> ~/.boa-constructor-src/Boa.desktop << EOF
#!/usr/bin/env xdg-open

[Desktop Entry]
Version=1.0
Type=Application
Terminal=false
Icon[en_US]=gnome-panel-launcher
Name[en_US]=Boa Constructor
Exec=$HOME/.boa-constructor-src/Boa.py
Comment[en_US]=Boa Constructor Python Integrated Development Environment
Name=Boa Constructor
Comment=Boa Constructor Python Integrated Development Environment
Icon=$HOME/.boa-constructor-src/Images/Icons/Boa.ico
EOF
chmod ug+x ~/.boa-constructor-src/Boa.desktop
chmod ug+x ~/.boa-constructor-src/Boa.py
# TODO: Put Boa in Programming menu with Aptana icon
# Temporary workaround:  Put link to Boa on the desktop
ln -s ~/.boa-constructor-src/Boa.desktop ~/Desktop

echo " - gedit plugins:  Auto Tab, Indent Lines, Reindent Python, Reopen Tabs, Snippets, Tab Close, Word Completion..."
# Download/extract to ~/.gnome2/gedit/plugins/
mkdir ~/.local/share/gedit
mkdir ~/.local/share/gedit/plugins
cd ~/.local/share/gedit/plugins
echo " - - Auto Tab"
wget http://gedit-autotab.googlecode.com/files/autotab-0.6.tar.gz
tar -xzf autotab-0.6.tar.gz
rm autotab-0.6.tar.gz
echo " - - Indent Lines"
wget -O reindent.gedit-plugin "http://live.gnome.org/Gedit/Plugins/Reindent?action=AttachFile&do=get&target=reindent.gedit-plugin"
wget -O reindent.py "http://live.gnome.org/Gedit/Plugins/Reindent?action=AttachFile&do=get&target=reindent.py"
echo " - - Reopen Tabs"
wget http://reopen-tabs-gedit-plugin.googlecode.com/files/reopen-tabs-gedit-plugin-0.3.5.tar.gz
tar -xzf reopen-tabs-gedit-plugin-0.3.5.tar.gz
rm reopen-tabs-gedit-plugin-0.3.5.tar.gz
echo " - - Tab Close"
wget http://blog.goranrakic.com/archives/fajlovi/gedit-tabclose-1.0.tar.gz
tar -xzf gedit-tabclose-1.0.tar.gz
mv gedit-tabclose/TabClose* .
rm gedit-tabclose-1.0.tar.gz
rm -rf gedit-tabclose
echo " - - Reopen Tabs"
wget http://reopen-tabs-gedit-plugin.googlecode.com/files/reopen-tabs-gedit-plugin-0.3.5.tar.gz
tar -xzf reopen-tabs-gedit-plugin-0.3.5.tar.gz
rm reopen-tabs-gedit-plugin-0.3.5.tar.gz
# echo " - - Word Completion"
# TODO: Try the default plugin for word completion, or http://elias.hiex.at/gedit-plugins/ as a replacement
# wget http://users.tkk.fi/~otsaloma/gedit/completion.gedit-plugin
# wget http://users.tkk.fi/~otsaloma/gedit/completion.png
# wget http://users.tkk.fi/~otsaloma/gedit/completion.py
# TODO: Try default bracket completion plugin, or http://code.google.com/p/gedit-pair-char-autocomplete/ for paired character completion
# TODO: Enable these default plugins:  code comment, multiedit, smart spaces, tag list, word completion, bracket completion
# Cleanup the extra files that were unzipped from several plugins
rm CHANGELOG
rm README
# Snippets is already installed by default
echo " - - Enabling gedit plugins..."
gedit_plugins=$(gconftool-2 --get /apps/gedit-2/plugins/active-plugins)
gedit_plugins=$(echo $gedit_plugins | tr -d "[]")
gedit_plugins="[$gedit_plugins,snippets,autotab,reopen-tabs,completion,TabClose,reindent,indent]"
gconftool-2 --set /apps/gedit-2/plugins/active-plugins --type list --list-type string $gedit_plugins
echo " - Installing Nautilus file templates..."
cd $setupdir
wget http://bazaar.launchpad.net/%7Ecaneypuggies/%2Bjunk/CaneyPUGgies_tools/download/tim%40alwaysreformed.com-20100602203740-wgrq5zqdhn8g4l5y/templates.tar.gz-20100602203722-fw7xyz1t8lj446jp-1/Templates.tar.gz
tar -xzf Templates.tar.gz
mv Templates/* ~/Templates
rm Templates.tar.gz
rm -rf Templates
echo " - Configuring Nautilus context menu actions for Meld & Clam Antivirus..."
gconftool-2 --set /apps/nautilus-actions/preferences/iprefs-level-zero --type list --list-type string [7cf2a88d-55c2-4daa-aa09-746d848826e5,ffb22615-e1bc-4bb1-b0f6-5b7a5d804904,bca26922-dbe0-440f-9e0f-9cf3621cef74]
echo " - - Compare two files in Meld"
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/accept-multiple-files --type bool true
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/basenames --type list --list-type string [*]
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/icon --type string /usr/share/pixmaps/meld.png
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/isdir --type bool true
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/isfile --type bool true
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/label --type string Compare
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/matchcase --type bool true
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/mimetypes --type list --list-type string [*/*]
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/parameters --type string %M
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/path --type string /usr/bin/meld
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/chemes --type list --list-type string [file,sftp,smb,ftp,dav]
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/tooltip --type string "Compare two files in Meld"
gconftool-2 --set /apps/nautilus-actions/configurations/7cf2a88d-55c2-4daa-aa09-746d848826e5/version --type string 1.1

echo " - - Diff with Meld"
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/accept-multiple-files --type bool true
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/basenames --type list --list-type string [*.*]
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/icon --type string /usr/share/pixmaps/meld.png
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/isdir --type bool false
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/isfile --type bool true
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/label --type string "Diff with Meld"
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/matchcase --type bool true
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/mimetypes --type list --list-type string [text/*]
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/parameters --type string %M
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/path --type string /usr/bin/meld
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/chemes --type list --list-type string [file]
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/tooltip --type string "Diff with Meld"
gconftool-2 --set /apps/nautilus-actions/configurations/bca26922-dbe0-440f-9e0f-9cf3621cef74/version --type string 1.1

echo " - - Scan for viruses"
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/accept-multiple-files --type bool true
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/basenames --type list --list-type string [*]
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/icon --type string gtk-dialog-warning
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/isdir --type bool true
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/isfile --type bool true
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/label --type string "Scan for viruses"
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/matchcase --type bool true
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/mimetypes --type list --list-type string [*/*]
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/parameters --type string %M
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/path --type string /usr/bin/clamtk
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/chemes --type list --list-type string [file]
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/tooltip --type string "Scan this file or directory using a virus scanner"
gconftool-2 --set /apps/nautilus-actions/configurations/ffb22615-e1bc-4bb1-b0f6-5b7a5d804904/version --type string 1.1

echo "Creating TurboGears 2.1 environment in the ~/Projects directory..."
echo " - Installing TurboGears dependencies"
sudo apt-get -y install build-essential python-dev python-setuptools python-virtualenv
echo " - Creating Virtual Environment..."
mkdir ~/Projects
cd ~/Projects

# Create virtual environment
virtualenv --no-site-packages tg21env
cd tg21env
# Activate virtual environment
# Note this command is equivalent to "source bin/activate" in bash, but we're using sh instead of bash
. bin/activate

# Install TurboGears 2.1
# TODO: For some reason this returns this error:
# error: Installed distribution ToscaWidgets 0.8.7.1dev-20110704 conflicts with requirement ToscaWidgets>0.9.7
# TODO: migrate these easy_install calls to use pip instead of easy_install
easy_install -i http://www.turbogears.org/2.1/downloads/current/index tg.devtools
# Install sqlalchemy-migrate
easy_install sqlalchemy-migrate

# Upgrade toscawidgets to >0.9.7
easy_install -U toscawidgets
# Upgrade genshi
easy_install -U genshi
# Fix ImportError: No module named pylonshq
easy_install repoze.what_pylons

# Get branch of Reformed Churches Locator
echo " - Making a local branch of the RCL Bazaar repository..."
cd ..
bzr branch lp:reformedchurcheslocator
echo " - Installing RCL into this virtual environment, downloading required packages..."
cd reformedchurcheslocator
python setup.py develop
echo " - Running nosetests as a smoke test to see if this TurboGears app is installed correctly..."
nosetests

echo " - HERE'S WHAT YOU NEED TO DO AFTER PRESSING 'ENTER' BELOW:"
echo "   1.  CTRL-click on the link in the terminal (usually http://127.0.0.1:8080 ) to open the Reformed Churches Locator application in your browser."
echo "   2.  Click around, login, play with the admin interface a little."
echo "   3.  If it's running satisfactorily, hit CTRL-C to kill the app."
echo " "
echo " - If something didn't work right, just delete the tg21env & reformedchurcheslocator directories in ~/Projects, (ask for help) fix(ing) this script, and try running it again."
echo " "
echo " - If everything installed correctly, then this installer is ALL DONE!"
echo " "
read -p "Press ENTER to continue: " enter
echo " "

echo " - Creating app's database & serving on default port (port 8080)..."
echo " "
paster setup-app development.ini
paster serve --reload development.ini


